Limitations
===========

Please note that :mod:`sjkabc` does not currently fully conform to the `ABC
music standard`_ as it does not implement all features and header keys. This is
the future goal, however, and contributions are very welcome.

.. _`ABC music standard`: http://abcnotation.com/wiki/abc:standard:v2.1
